@@ -3,11 +3,10 @@ from __future__ import annotations
 from datetime import datetime, timezone
 from typing import Annotated, Any, Callable, Optional
 
-from fastapi import Body, Depends, HTTPException, Query, Request, Security
+from fastapi import Depends, HTTPException, Request
 from fastapi.security import APIKeyCookie, APIKeyHeader, OAuth2PasswordBearer
 from sqlalchemy import select
 
-from svc_infra.api.fastapi.auth.mfa import MFAProof, verify_mfa_for_user
 from svc_infra.api.fastapi.auth.settings import get_auth_settings
 from svc_infra.api.fastapi.auth.state import get_auth_state, get_user_scope_resolver
 from svc_infra.api.fastapi.db.sql.session import SqlSessionDep
@@ -34,8 +33,10 @@ class Principal:
 
 # ---------- Resolvers ----------
 async def resolve_api_key(
-    request: Request, session: SqlSessionDep, raw: Optional[str] = Security(api_key_header)
+    request: Request,
+    session: SqlSessionDep,
 ) -> Optional[Principal]:
+    raw = (request.headers.get("x-api-key") or "").strip()
     if not raw:
         return None
     ApiKey = get_apikey_model()
@@ -43,6 +44,7 @@ async def resolve_api_key(
     parts = raw.split("_", 2)
     if len(parts) >= 3 and parts[0] == "ak":
         prefix = parts[1][:12]
+
     apikey = None
     if prefix:
         apikey = (
@@ -64,7 +66,6 @@ async def resolve_api_key(
 
     apikey.mark_used()
     await session.flush()
-
     return Principal(user=apikey.user, scopes=apikey.scopes, via="api_key", api_key=apikey)
 
 
@@ -116,7 +117,6 @@ async def resolve_bearer_or_cookie_principal(
     return Principal(user=db_user, scopes=scopes, via=via)
 
 
-# ---------- Unifying dependencies ----------
 async def _current_principal(
     request: Request,
     session: SqlSessionDep,
@@ -193,31 +193,3 @@ def RequireService():
         return p
 
     return Depends(_guard)
-
-
-def RequireMFAIfEnabled(body_field: str = "mfa"):
-    """
-    Requires MFA iff the current user has MFA enabled.
-    Looks for proof in the request body under `body_field` (e.g. "mfa"),
-    and falls back to query params ?mfa_code=&mfa_pre_token= for methods that
-    may not send bodies (e.g. DELETE).
-    """
-
-    async def _dep(
-        p: Identity,
-        sess: SqlSessionDep,
-        mfa: Optional[MFAProof] = Body(None, embed=True, alias=body_field),
-        mfa_code: Optional[str] = Query(None, alias="mfa_code"),
-        mfa_pre_token: Optional[str] = Query(None, alias="mfa_pre_token"),
-    ):
-        proof = mfa or (
-            MFAProof(code=mfa_code, pre_token=mfa_pre_token) if mfa_code or mfa_pre_token else None
-        )
-        res = await verify_mfa_for_user(
-            user=p.user, session=sess, proof=proof, require_enabled=True
-        )
-        if not res.ok:
-            raise HTTPException(400, "Invalid code")
-        return p
-
-    return Depends(_dep)
