@@ -7,7 +7,6 @@ from typing import Iterable, Sequence
 
 from fastapi import FastAPI
 from fastapi.middleware.cors import CORSMiddleware
-from fastapi.openapi.utils import get_openapi
 from fastapi.responses import HTMLResponse
 from fastapi.routing import APIRoute
 
@@ -16,10 +15,25 @@ from svc_infra.api.fastapi.middleware.errors.catchall import CatchAllExceptionMi
 from svc_infra.api.fastapi.middleware.errors.handlers import register_error_handlers
 from svc_infra.api.fastapi.openapi.models import APIVersionSpec, ServiceInfo
 from svc_infra.api.fastapi.openapi.mutators import (
+    attach_standard_responses_mutator,
     auth_mutator,
     conventions_mutator,
+    drop_unused_components_mutator,
+    ensure_examples_for_json_mutator,
+    ensure_global_tags_mutator,
+    ensure_media_examples_mutator,
+    ensure_media_type_schemas_mutator,
+    ensure_operation_descriptions_mutator,
+    ensure_parameter_metadata_mutator,
+    ensure_request_body_descriptions_mutator,
+    ensure_response_descriptions_mutator,
+    improve_success_response_descriptions_mutator,
     info_mutator,
+    normalize_no_content_204_mutator,
+    normalize_problem_and_examples_mutator,
+    prune_invalid_responses_keys_mutator,
     servers_mutator,
+    strip_ref_siblings_in_responses_mutator,
 )
 from svc_infra.api.fastapi.openapi.pipeline import apply_mutators
 from svc_infra.api.fastapi.routers import register_all_routers
@@ -86,69 +100,6 @@ def _coerce_list(value: str | Iterable[str] | None) -> list[str]:
     return [v for v in value if v]
 
 
-def _apply_info_overrides(app: FastAPI, base: ServiceInfo, spec: APIVersionSpec | None = None):
-    """Apply base ServiceInfo + optional per-child overrides into OpenAPI.info."""
-    prev = getattr(app, "openapi", None)
-
-    def patched():
-        base_schema = (
-            prev()
-            if callable(prev)
-            else get_openapi(title=app.title, version=app.version, routes=app.routes)
-        )
-        schema = dict(base_schema)
-        info = schema.setdefault("info", {})
-        # Base service identity
-        info.setdefault("title", base.name)
-        info.setdefault("version", base.release)
-        if base.description is not None:
-            info["description"] = base.description
-        if base.terms_of_service is not None:
-            info["termsOfService"] = base.terms_of_service
-        if base.contact:
-            info["contact"] = {k: v for k, v in base.contact.model_dump().items() if v is not None}
-        if base.license:
-            info["license"] = {k: v for k, v in base.license.model_dump().items() if v is not None}
-        # Per-child overrides
-        if spec is not None:
-            if spec.description is not None:
-                info["description"] = spec.description
-            if spec.terms_of_service is not None:
-                info["termsOfService"] = spec.terms_of_service
-            if spec.contact is not None:
-                info["contact"] = {
-                    k: v for k, v in spec.contact.model_dump().items() if v is not None
-                }
-            if spec.license is not None:
-                info["license"] = {
-                    k: v for k, v in spec.license.model_dump().items() if v is not None
-                }
-
-        app.openapi_schema = schema
-        return schema
-
-    app.openapi = patched
-
-
-def _set_servers(app: FastAPI, public_base_url: str | None, mount_path: str):
-    """Install servers AFTER all other installers so it wins."""
-    base = mount_path if not public_base_url else f"{public_base_url.rstrip('/')}{mount_path}"
-    previous = getattr(app, "openapi", None)
-
-    def custom_openapi():
-        base_schema = (
-            previous()
-            if callable(previous)
-            else get_openapi(title=app.title, version=app.version, routes=app.routes)
-        )
-        schema = dict(base_schema)
-        schema["servers"] = [{"url": base}]
-        app.openapi_schema = schema
-        return schema
-
-    app.openapi = custom_openapi
-
-
 def _dump_or_none(model):
     return model.model_dump(exclude_none=True) if model is not None else None
 
@@ -176,13 +127,28 @@ def _build_child_app(service: ServiceInfo, spec: APIVersionSpec) -> FastAPI:
         else f"{spec.public_base_url.rstrip('/')}{mount_path}"
     )
 
-    apply_mutators(
-        child,
+    mutators = [
         conventions_mutator(),
+        normalize_problem_and_examples_mutator(),
+        attach_standard_responses_mutator(),
         auth_mutator(include_api_key),
+        strip_ref_siblings_in_responses_mutator(),
+        prune_invalid_responses_keys_mutator(),
+        ensure_operation_descriptions_mutator(),
+        ensure_request_body_descriptions_mutator(),
+        ensure_parameter_metadata_mutator(),
+        ensure_media_type_schemas_mutator(),
+        ensure_examples_for_json_mutator(),
+        normalize_no_content_204_mutator(),
+        ensure_response_descriptions_mutator(),
+        improve_success_response_descriptions_mutator(),
+        ensure_global_tags_mutator(),
+        drop_unused_components_mutator(),
         info_mutator(service, spec),
+        ensure_media_examples_mutator(),
         servers_mutator(server_url),
-    )
+    ]
+    apply_mutators(child, *mutators)
 
     if spec.routers_package:
         register_all_routers(
@@ -201,6 +167,7 @@ def _build_parent_app(
     public_cors_origins: list[str] | str | None,
     root_routers: list[str] | str | None,
     root_server_url: str | None = None,
+    root_include_api_key: bool = False,  # <-- NEW
 ) -> FastAPI:
     parent = FastAPI(
         title=service.name,
@@ -218,9 +185,27 @@ def _build_parent_app(
     parent.add_middleware(CatchAllExceptionMiddleware)
     register_error_handlers(parent)
 
-    # OpenAPI pipeline on root (same cleansing as child)
-    mutators = [conventions_mutator(), info_mutator(service, None)]
-    if root_server_url:  # optional: only force if provided
+    mutators = [
+        conventions_mutator(),
+        normalize_problem_and_examples_mutator(),
+        attach_standard_responses_mutator(),
+        auth_mutator(root_include_api_key),
+        strip_ref_siblings_in_responses_mutator(),
+        prune_invalid_responses_keys_mutator(),
+        ensure_operation_descriptions_mutator(),
+        ensure_request_body_descriptions_mutator(),
+        ensure_parameter_metadata_mutator(),
+        ensure_media_type_schemas_mutator(),
+        ensure_examples_for_json_mutator(),
+        normalize_no_content_204_mutator(),
+        ensure_response_descriptions_mutator(),
+        improve_success_response_descriptions_mutator(),
+        ensure_global_tags_mutator(),
+        drop_unused_components_mutator(),
+        info_mutator(service, None),
+        ensure_media_examples_mutator(),
+    ]
+    if root_server_url:
         mutators.append(servers_mutator(root_server_url))
     apply_mutators(parent, *mutators)
 
@@ -245,14 +230,22 @@ def setup_service_api(
     root_routers: list[str] | str | None = None,
     public_cors_origins: list[str] | str | None = None,
     root_public_base_url: str | None = None,
+    root_include_api_key: bool | None = None,
 ) -> FastAPI:
-    # Build parent with its own mutators applied
+    # infer if not explicitly provided
+    effective_root_include_api_key = (
+        any(bool(v.include_api_key) for v in versions)
+        if root_include_api_key is None
+        else bool(root_include_api_key)
+    )
+
     root_server = root_public_base_url.rstrip("/") if root_public_base_url else "/"
     parent = _build_parent_app(
         service,
         public_cors_origins=public_cors_origins,
         root_routers=root_routers,
         root_server_url=root_server,
+        root_include_api_key=effective_root_include_api_key,
     )
 
     # Mount each version
